
CREATE INDEX ndxDocumento ON MovimientosBanco (TipoDocRel ASC, NumeroDocRel ASC)

CREATE TABLE Cobranzas(
	id bigint IDENTITY(1,1) PRIMARY KEY NOT NULL,
	sesion int NOT NULL,
	idOperador nvarchar(8) NOT NULL,
	codVend nvarchar(20) NOT NULL,
	codCli nvarchar(20) NOT NULL,
	Fecha datetime NOT NULL,
	tipoDoc nvarchar(3) NOT NULL,
	numDoc int NOT NULL,
	MontoCobrado money NOT NULL DEFAULT (0),
	MontoNeto money NOT NULL DEFAULT (0),
	RetencionIVA money NOT NULL DEFAULT (0),
	RetencionISLR money NOT NULL DEFAULT (0),
	NetoFacturas money NOT NULL DEFAULT (0),
	IVACobrado money NOT NULL DEFAULT (0),
	Descuentos money NOT NULL DEFAULT (0),
	Descripcion nvarchar(50) NOT NULL
)
GO

CREATE TABLE [dbo].[DetallesCobranza](
			[id] [bigint] IDENTITY(1,1) PRIMARY KEY NOT NULL, 
			[NumeroCobranza] [bigint] NOT NULL, 
			[NumeroDoc] [int] NOT NULL, 
			[TipoDoc] [nvarchar](3) NOT NULL, 
			[MontoCobrado] [money] NOT NULL DEFAULT (0), 
			[MontoNeto] [money] NOT NULL DEFAULT (0), 
			[RetencionIVA] [money] NOT NULL DEFAULT (0), 
			[RetencionISLR] [money] NOT NULL DEFAULT (0), 
			[NetoFacturas] [money] NOT NULL DEFAULT (0),
			[IVACobrado] [money] NOT NULL DEFAULT (0), 
			[Descuentos] [money] NOT NULL CONSTRAINT [DF_DetallesCobranza_Descuentos]  DEFAULT (0))
GO

ALTER TABLE DetallesCobranza  WITH CHECK ADD CONSTRAINT FK_DetallesCobranza_Cobranzas FOREIGN KEY(NumeroCobranza) 
	REFERENCES Cobranzas (id) ON UPDATE CASCADE ON DELETE CASCADE

CREATE INDEX IX_Cobranzas_VendedorFecha ON Cobranzas (codVend ASC, Fecha ASC);

ALTER TABLE RetencionesIVA
  ADD Fecha DATETIME,
      TipoDocFiscal NVARCHAR (3),
      Referencia NVARCHAR(30),
      NumeroControlInicial NVARCHAR(16),
      Exento MONEY, 
      Gravable1 MONEY,
      Gravable2 MONEY,
      Impuesto1 MONEY,
      Impuesto2 MONEY,
      RifEntidad NVARCHAR(14),
      NombreENtidad NVARCHAR(50)
GO


UPDATE RetencionesIVA
  SET Fecha = D.Fecha, TipoDocFiscal = D.TipoDocFiscal, 
      Referencia = D.Referencia, NumeroControlInicial = D.NumeroControlInicial,
      Exento = D.Exento, Gravable1 = D.Gravable1, Gravable2 = D.Gravable2,
      Impuesto1 = D.Impuesto1, Impuesto2 = D.Impuesto2, 
      RIFEntidad = D.RifEntidad, NombreEntidad = D.NombreEntidad
FROM DocumentosFiscales D
WHERE D.TipoDoc = RetencionesIVA.tipoDoc 
  AND D.NumeroDOC = RetencionesIVA.NumFactura 
  AND D.TipoEntidad = 'CLT'

CREATE TABLE tmpTransferencias (
	ID int IDENTITY (1, 1) PRIMARY KEY NOT NULL,
	FechaRegistro datetime NOT NULL,
	Descripcion nvarchar (50) NOT NULL,
	almacenOrigen nvarchar (8) NOT NULL,
	almacenDestino nvarchar (8) NOT NULL,
	operador nvarchar (12) NOT NULL,
	Notas nvarchar (255) NOT NULL 
)

CREATE TABLE tmpTransferenciasDetalles (
	transID int NOT NULL,
	Renglon int IDENTITY (1, 1) PRIMARY KEY NOT NULL,
	CodigoItem nvarchar (20) NOT NULL,
	Cantidad float NOT NULL 
)
GO

CREATE  UNIQUE  INDEX IX_tmpTransferenciasDetalles ON tmpTransferenciasDetalles(transID, Renglon)

ALTER TABLE tmpTransferenciasDetalles ADD CONSTRAINT FK_tmpTransfDet_tmpTransf 
	FOREIGN KEY (transID) REFERENCES tmpTransferencias (ID)
	ON UPDATE CASCADE ON DELETE CASCADE
