Option Explicit

' ===================================================================
' Carga registros a la BBDD.
' Los registros estn contenidos en un archivo de texto llamado
' "ImportData.txt", en la carpeta de datos de la empresa.
' Si se quiere cambiar el nombre del archivo, se modificar la 
' constante FILE_NAME, definida a continuacion.
' Los archivos de datos a importar estn formados por uno o mas 
' segmentos de lneas, con la siguiente estructura
'   IdTabla
'		fldDescs
'		dataRows
' Donde:
'		IdTabla::= '[BEGTABLE ' <nombreTabla> ']'
'   fldDescs::= <fldDesc> {'\t'<fldDesc>}
'			fldDesc::=<fldName>:<fldType>
'				fldName::=/* cualquier secuencia de caracteres que no incluya los dos puntos */
'				fldType::= <digito>{<digito>}
'		dataRows::={<dataRow>}
'			dataRow::=<dato>{'\t'<dato>}

Const FILE_NAME = "metodosISLR.txt"

Private fldDescs(), nFields
Private tableName
Private rex
Private outDevice
Private sb

' Descriptor de los campos de la tabla en proceso
Class FieldDesc
	Public fldName, fldType
	
	Public Function ToString()
		ToString = fldName & "(" & fldType & ")"
	End Function
	
	' Hace un casting explicito del valor en funcion del tipo de dato ADO
	' es requerido para asegurar que ExecuteSQL tome los valores correctos
	Public Default Function typedValue(arg)
	Dim retVal
		Select Case fldType
			Case 2
				retVal = CInt(arg)
			Case 3, 20
				retVal = CLng(arg)
			Case 5
				retVal = CDbl(arg)
			Case 6
				retVal = CCur(arg)
			Case 17
				retVal = CByte(arg)
			Case 135
				retVal = CDate(arg)
			Case 201, 202
				retVal = CStr(arg)
		End Select
		typedValue = retVal
	End Function
	
End Class


' Determina si la linea contiene el inicio de una nueva tabla, almacen el nombre en <nombreTabla>
Private Function isTableHeader(s)
Dim isHeader, pattern
	rex.pattern = "\[BEGTABLE\s([^\]]+)\]"
	isHeader = rex.Test(s)
	If isHeader Then
		If tableName <> "" Then
			On Error Resume Next
			' Se requiere si la tabla tiene campos identity
			ExecuteSQL "SET IDENTITY_INSERT " & tableName & " OFF"
			If Err.Number Then Err.Clear
			On Error Goto 0
		End If
		tableName = Left(Mid(s, 11), Len(s) - 11)
		outDevice.Send "TABLA: " & tableName
		On Error Resume Next
		ExecuteSQL "SET IDENTITY_INSERT " & tableName & " ON"
		If Err.Number Then Err.Clear
		On Error Goto 0
	End If
	isTableHeader = isHeader
End Function


' Obtiene los descriptores de columnas (fldDesc)
Private Sub getFieldsDesc(s)
Dim maxFlds, qFlds, matches, match, f
  
	maxFlds = 100
	Redim fldDescs(maxFlds)
	qFlds = 0
	rex.Pattern = "[^:\s]+:\d+"
	rex.Global = True
	Set matches = rex.Execute(s)
	For each match In Matches
		Dim v, fld
		v = Split(match.value, ":")
		Set f = New FieldDesc
		f.fldName = v(0)
		f.fldType = v(1)
		Set fldDescs(qFlds) = f
		qFlds = qFlds + 1
		If qFlds > maxFlds Then
			maxFlds = maxFlds + 100
			Redim Preserve fldDescs(maxFlds)
		End If
	Next
	Redim Preserve fldDescs(qFlds - 1)
	
	For match = 0 To qFlds - 1
		outDevice.Send fldDescs(match).ToString
	Next
	nFields = qFlds
End Sub	


' Llena la lista de campos para la sentencia SQL de insercion
Private Function fldNamesList()
Dim sb, n
	Set sb = CreateObject("VSLIB.CStringBuffer")
	sb.Value = "("
	For n = 0 To nFields - 1
		If n Then sb.Append ", "
		sb.Append fldDescs(n).fldName
	Next
	sb.Append ")"
	fldNamesList = sb.Value
End Function


' Llena la lista de marcadores (?, ?, ...) para la sentencia de insercion
Private Function markersList()
Dim sb, n
	Set sb = CreateObject("VSLIB.CStringBuffer")
	sb.Value = "("
	For n = 0 To nFields - 1
		If n Then sb.Append ", "
		sb.Append "?"
	Next
	sb.Append ")"
	markersList = sb.Value
End Function


' Procesa una fila de datos
Private Sub processRow(s)
Dim v, arr(), n
	v = Split(s, Chr(9))
	Redim arr(nFields - 1)
	For n = 0 To nFields - 1
		arr(n) = fldDescs(n).typedValue(v(n))
	Next
	sb.Value = "INSERT INTO " & TableName & fldNamesList & " VALUES " & markersList
	ExecuteSQLA sb.Value, arr
End Sub



' Rutina principal (punto de entrada)
Public Sub Main()
Dim fileName, inFile, fso, laLinea
Dim n

	fileName = DataPath & FILE_NAME
	Set fso = CreateObject("Scripting.FileSystemObject")
	Set inFile = fso.OpenTextFile(fileName, 1, False)

	If inFile.AtEndOfStream Then
		MsgBox "El archivo est vaco"
		Exit Sub
	End If

	ExecuteSQL "DELETE FROM rislrMetodos"
	Set sb = CreateObject("VSLIB.CStringBuffer")
	Set rex = New RegExp
	Set outDevice = CreateObject("OutDevice.COutDev")
	outDevice.DeviceName = "frm:Prueba"
	tableName = ""
	Do
		laLinea = inFile.ReadLine
		If isTableHeader(laLinea) Then
			outDevice.Send laLinea
			laLinea = inFile.ReadLine
			outDevice.Send laLinea
			getFieldsDesc laLinea
		Else
			processRow laLinea
		End If
	Loop While Not inFile.AtEndOfStream
	' Resetar IDENTITY_INSERT para la ltima tabla
	If tableName <> "" Then
		On Error Resume Next
		ExecuteSQL "SET IDENTITY_INSERT " & tableName & " OFF"
		If Err.Number Then Err.Clear
		On Error Goto 0
	End If
  inFile.Close
	outDevice.Cerrar
End Sub
