ALTER Table SesionesCerradas
  ADD PrimeraFactura INT NOT NULL DEFAULT 0,
  UltimaFactura INT NOT NULL DEFAULT 0
GO

ALTER Table SesionesPOS
  ADD PrimeraFactura INT NOT NULL DEFAULT 0,
  UltimaFactura INT NOT NULL DEFAULT 0
GO

UPDATE SesionesCerradas
  SET PrimeraFactura = COALESCE((SELECT MIN(NumeroTicket) FROM FacturasPOS WHERE idSesion = SessionID), 0),
      UltimaFactura = COALESCE((SELECT MAX(NumeroTicket) FROM FacturasPOS WHERE idSesion = SessionID), 0)

UPDATE SesionesPOS
  SET PrimeraFactura = COALESCE((SELECT MIN(NumeroTicket) FROM FacturasPOS WHERE idSesion = SessionID), 0),
      UltimaFactura = COALESCE((SELECT MAX(NumeroTicket) FROM FacturasPOS WHERE idSesion = SessionID), 0)

CREATE TABLE dbo.acumuladoresTipoIVASesion(
	numeroSesion int NOT NULL DEFAULT 0,
	tipoImpuesto nvarchar(3) NOT NULL DEFAULT '',
	valorAcumulado money NOT NULL DEFAULT 0,
	porcentajeIVA float NOT NULL DEFAULT 0, 
 CONSTRAINT PK_acumuladoresTipoIVASesion PRIMARY KEY CLUSTERED 
(
	numeroSesion,
	tipoImpuesto,
	porcentajeIVA
)
)
GO

INSERT INTO acumuladoresTipoIVASesion (numeroSesion, tipoImpuesto, valorAcumulado)
	SELECT S.SessionID, I.TipoImpuesto1, SUM(PrecioUnitario * Cantidad)
	FROM SesionesCerradas S INNER JOIN FacturasPOS F ON SessionID = idSesion
	  INNER JOIN RenglonesFacturaPOS ON numeroFactura = Numero
	  INNER JOIN itemsVenta I on Codigo = Producto
	GROUP BY SessionID, TipoImpuesto1

INSERT INTO acumuladoresTipoIVASesion (numeroSesion, tipoImpuesto, valorAcumulado)
	SELECT S.SessionID, I.TipoImpuesto1, SUM(PrecioUnitario * Cantidad)
	FROM SesionesPOS S INNER JOIN FacturasPOS F ON SessionID = idSesion
	  INNER JOIN RenglonesFacturaPOS ON numeroFactura = Numero
	  INNER JOIN itemsVenta I on Codigo = Producto
	GROUP BY SessionID, TipoImpuesto1

GO

CREATE TRIGGER AcumularIVASesion
   ON  RenglonesFacturaPOS 
   FOR INSERT,DELETE,UPDATE
AS 
BEGIN
	SET NOCOUNT ON;
	INSERT INTO acumuladoresTipoIVASesion (numeroSesion, tipoImpuesto, porcentajeIVA)
	SELECT F.idSesion, I.TipoImpuesto1, T.porcentaje
	FROM FacturasPOS F INNER JOIN INSERTED ON numero = numeroFactura
		INNER JOIN itemsVenta I ON I.codigo = producto
		INNER JOIN tiposImpuesto T ON T.Codigo = I.TipoImpuesto1
	WHERE NOT Exists (SELECT * FROM acumuladoresTipoIVASesion WHERE numeroSesion = F.idSesion AND tipoImpuesto = I.TipoImpuesto1 AND porcentajeIVA = T.Porcentaje)

	UPDATE acumuladoresTipoIVASesion
	SET valorAcumulado = valorAcumulado + (precioUnitario * cantidad)
	FROM FacturasPOS F INNER JOIN INSERTED ON numero = numeroFactura
		INNER JOIN itemsVenta I ON I.codigo = producto
		INNER JOIN TiposImpuesto T ON T.Codigo = I.TipoImpuesto1
	WHERE tipoImpuesto = tipoImpuesto1 AND porcentaje = porcentajeIVA
	AND numeroSesion = idSesion

	UPDATE acumuladoresTipoIVASesion
	SET valorAcumulado = valorAcumulado - (precioUnitario * cantidad)
	FROM FacturasPOS F INNER JOIN DELETED ON numero = numeroFactura
		INNER JOIN itemsVenta I ON I.codigo = producto
		INNER JOIN TiposImpuesto T ON T.Codigo = I.TipoImpuesto1
	WHERE tipoImpuesto = tipoImpuesto1 AND porcentaje = porcentajeIVA
	AND numeroSesion = idSesion
END

GO

CREATE TRIGGER actualizarNumerosSesion  
   ON  FacturasPOS 
   FOR INSERT, UPDATE
AS 
BEGIN
	SET NOCOUNT ON;
	UPDATE SesionesPOS set UltimaFactura = NumeroTicket
	FROM INSERTED WHERE idSesion = SessionID;

	UPDATE SesionesPOS SET PrimeraFactura = NumeroTicket
	FROM INSERTED WHERE idSesion = SessionID 
	AND primeraFactura = 0
END
GO
