-- Script de actualizacion para bases de datos de ClearLight
-- Versin: 7.10
-- Fecha: 24-Mar-2015

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'parametrosEmpresa' AND COLUMN_NAME = 'Version')
BEGIN
	ALTER TABLE ParametrosEmpresa
		ADD version INT NOT NULL DEFAULT 7016
END

DECLARE @dbVersion INT, @cmd NVARCHAR(255)
SET @dbVersion = 7016
SET @cmd = 'UPDATE ParametrosEmpresa SET version = ' + CONVERT(NVARCHAR(5), @dbVersion)
EXEC sp_executesql @cmd

DECLARE @n INT
IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.Columns WHERE TABLE_NAME = 'Proveedores' AND Column_Name = 'tipoPersona')
BEGIN
  ALTER TABLE Proveedores ADD tipoPersona TINYINT NOT NULL Default 2
END

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.Columns WHERE TABLE_NAME = 'Usuarios' AND Column_Name = 'uniqid')
BEGIN
  ALTER TABLE Usuarios ADD uniqid NVARCHAR(23) NOT NULL Default ''
END

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.Columns WHERE TABLE_NAME = 'Usuarios' AND Column_Name = 'TEMA')
BEGIN
  ALTER TABLE Usuarios ADD tema NVARCHAR(20) NOT NULL DEFAULT 'Default'
END


IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.Columns WHERE TABLE_NAME = 'NNEEDevDetalles' AND Column_Name = 'RENGLON')
BEGIN
  ALTER TABLE NNEEDevDetalles ADD Renglon INT NOT NULL DEFAULT 0
END

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.Columns WHERE TABLE_NAME = 'Vendedores' AND Column_Name = 'cuentaPasivo')
BEGIN
  ALTER TABLE Vendedores ADD cuentaPasivo NVARCHAR(20) NOT NULL DEFAULT ''
END

IF NOT EXISTS(SELECT * FROM information_schema.tables where table_name = 'nomParametrosGenerales')
BEGIN
  Create Table nomParametrosGenerales (
    sueldoMinimo MONEY Not Null Default 0
  )
  INSERT INTO nomParametrosGenerales (sueldoMinimo) VALUES (2456.4)
END

IF NOT Exists(SELECT * FROM INFORMATION_SCHEMA.Columns WHERE TABLE_NAME = 'nomTrabajadores' AND Column_Name = 'ganaSueldoMinimo')
BEGIN
  ALTER TABLE nomTrabajadores ADD ganaSueldoMinimo SMALLINT NOT NULL DEFAULT 0
END

IF NOT Exists(SELECT * FROM INFORMATION_SCHEMA.Columns WHERE TABLE_NAME = 'nomTrabajadores' AND Column_Name = 'activo')
BEGIN
  ALTER TABLE nomTrabajadores ADD activo SMALLINT NOT NULL DEFAULT 1
END

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.Columns WHERE TABLE_NAME = 'nomTrabajadores' AND COLUMN_NAME = 'cuentaBancaria')
BEGIN
  ALTER TABLE nomTrabajadores ADD cuentaBancaria NVARCHAR(20) NOT NULL DEFAULT ''
END

SET @n = (SELECT Character_Maximum_Length FROM information_schema.columns WHERE Table_Name = 'MediosPago' And Column_Name = 'Descripcion')
IF @n < 40 ALTER TABLE MediosPago ALTER COLUMN Descripcion NVARCHAR(40)

-- Creacion de la tabla de eliminacion de detallesPOS

IF Not Exists (SELECT * FROM information_schema.tables where table_name = 'EliminacionesPOS')
BEGIN
  CREATE TABLE EliminacionesPOS(
	id int IDENTITY(1,1) PRIMARY KEY NOT NULL,
	Sesion int NOT NULL,
	Maquina smallint NOT NULL,
	Cuenta nvarchar(14) NOT NULL DEFAULT '',
	Producto nvarchar(20) NOT NULL,
	Precio money NOT NULL,
	Cantidad float NOT NULL,
	Autorizado nvarchar(12) NOT NULL DEFAULT '',
	Hora datetime NOT NULL DEFAULT getdate(),
	numCta int NOT NULL DEFAULT 0
  )

  CREATE INDEX ix_sesion ON EliminacionesPOS (Sesion)
END

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.Columns WHERE TABLE_NAME = 'mnuItems' AND COLUMN_NAME = 'textColor')
BEGIN
  ALTER TABLE mnuItems ADD textColor INT NOT NULL DEFAULT 0
END

IF NOT EXISTS (SELECT * FROM information_schema.tables where table_name = 'saveMovsCaja')
BEGIN
	CREATE TABLE saveMovsCaja(
		id int IDENTITY(1,1) PRIMARY KEY NOT NULL,
		clave nvarchar(20) NOT NULL
	)
	CREATE UNIQUE NONCLUSTERED INDEX IX_saveMovCaja ON saveMovsCaja (clave)

	CREATE TABLE saveDetallesCaja(
		id int IDENTITY(1,1) PRIMARY KEY NOT NULL,
		transID int NOT NULL,
		Medio nvarchar(8) NOT NULL,
		Emisor nvarchar(20) NOT NULL,
		numeroDocumento nvarchar(20) NOT NULL,
		claveAutorizacion nvarchar(6) NOT NULL,
		monto money NOT NULL,
		numeroCuenta nvarchar(20) NOT NULL,
		idTitular nvarchar(20) NOT NULL,
		montoNominal money NOT NULL
	)

	ALTER TABLE saveDetallesCaja  WITH CHECK ADD  CONSTRAINT FK_saveDetallesCaja_saveMovCaja FOREIGN KEY(transID)
	REFERENCES saveMovsCaja (id)
	ON DELETE CASCADE

	CREATE TABLE saveDenominaciones(
		id bigint IDENTITY(1,1) PRIMARY KEY NOT NULL,
		idDetalle int NOT NULL,
		Denominacion money NOT NULL,
		CantidadRecibida int NOT NULL
	)

	ALTER TABLE saveDenominaciones  WITH CHECK ADD  CONSTRAINT FK_saveDenominaciones_saveDetallesCaja FOREIGN KEY(idDetalle)
	REFERENCES saveDetallesCaja (id)
	ON DELETE CASCADE
END

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'parametrosEmpresa' AND COLUMN_NAME = 'ClaveActivacionV7')
BEGIN
  ALTER TABLE parametrosEmpresa ADD claveActivacionV7 INT NOT NULL DEFAULT 0
  EXEC SP_EXECUTESQL N'UPDATE parametrosEmpresa SET claveActivacionV7 = claveActivacion'
END

IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME = 'HistoriaIVA')
BEGIN
  CREATE TABLE historiaIVA (
    id  INT IDENTITY(1, 1) PRIMARY KEY NOT NULL,
    tipo TINYINT NOT NULL,
    fechaInicioVigencia DATETIME NOT NULL,
    alicuota float NOT NULL
  )

  INSERT INTO historiaIVA (tipo, fechaInicioVigencia, alicuota) VALUES (1, '18000101', 0)
  INSERT INTO historiaIVA (tipo, fechaInicioVigencia, alicuota) VALUES (2, '18000101', 0)
  INSERT INTO historiaIVA (tipo, fechaInicioVigencia, alicuota) VALUES (1, '19931001', 10)
  INSERT INTO historiaIVA (tipo, fechaInicioVigencia, alicuota) VALUES (1, '19950101', 12.5)
  INSERT INTO historiaIVA (tipo, fechaInicioVigencia, alicuota) VALUES (1, '19960801', 16.5)
  INSERT INTO historiaIVA (tipo, fechaInicioVigencia, alicuota) VALUES (1, '20000801', 14.5)
  INSERT INTO historiaIVA (tipo, fechaInicioVigencia, alicuota) VALUES (1, '20020301', 16)
  INSERT INTO historiaIVA (tipo, fechaInicioVigencia, alicuota) VALUES (1, '20040901', 15)
  INSERT INTO historiaIVA (tipo, fechaInicioVigencia, alicuota) VALUES (1, '20051001', 14)
  INSERT INTO historiaIVA (tipo, fechaInicioVigencia, alicuota) VALUES (1, '20070301', 11)
  INSERT INTO historiaIVA (tipo, fechaInicioVigencia, alicuota) VALUES (1, '20090401', 12)
  INSERT INTO historiaIVA (tipo, fechaInicioVigencia, alicuota) VALUES (2, '20051001', 8)
END
GO

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.PARAMETERS WHERE SPECIFIC_NAME = 'IVAFecha')
BEGIN
  exec sp_executesql N'CREATE FUNCTION IVAFecha(@tipo as tinyInt, @Fecha AS DATETIME) 
  RETURNS FLOAT AS
  BEGIN
    DECLARE @retVal FLOAT
    SELECT @retVal = COALESCE(alicuota, 0) 
          FROM historiaIVA WHERE tipo = @tipo AND FechaInicioVigencia = (
              SELECT MAX(FechaInicioVigencia)
              FROM historiaIVA
              WHERE tipo = @tipo 
              AND fechaInicioVigencia <= @fecha
    )
    RETURN @retVal
  END'
END

GO

-- V7.2

IF NOT Exists(select * from information_schema.columns where table_Name = 'mesasMesas' and Column_Name = 'id')
BEGIN
  alter Table mesasMesas
    ADD id int identity (1, 1) NOT NULL
  create unique index ndx_id_mesasMesas ON mesasMesas (id)
END

If Not exists(select * from information_schema.columns WHERE Table_Name = 'cuentasPOS' And column_name = 'ownerID')
BEGIN
	DROP TABLE RenglonesCuentaPOS
	If EXISTS(select * from information_schema.columns WHERE Table_Name = 'renglonesComanda') DROP TABLE RenglonesComanda
	DROP TABLE CuentasPOS
	
	CREATE TABLE CuentasPOS (
		IDCuenta int IDENTITY (1, 1) PRIMARY KEY NOT NULL ,
		tipo tinyint NOT NULL DEFAULT 0,
		ownerID INT NOT NULL DEFAULT 0,
		CodigoCuenta nvarchar (20) NOT NULL DEFAULT '',
		HoraApertura datetime NOT NULL DEFAULT getdate(),
		HoraUltimaTransaccion datetime NOT NULL DEFAULT getdate(),
		Vendedor nvarchar (20) NOT NULL DEFAULT '',
		Estado smallint NOT NULL DEFAULT 0,
		Personas int NOT NULL DEFAULT 1,
		Cliente nvarchar (20) NOT NULL DEFAULT '',
		Ambiente nvarchar (16) NOT NULL DEFAULT '',
		idMesa int NOT NULL DEFAULT 0,
		Condiciones nvarchar (12) DEFAULT '' ,
		Extra nvarchar (12) NOT NULL DEFAULT '', 
		Bloqueada INT NOT NULL DEFAULT 0,
		Correlativo int not null default 0,
		codigoDescuento NVARCHAR(12) NOT NULL DEFAULT '',
		autorizadoDescuento NVARCHAR(12) NOT NULL DEFAULT '',
		explicacionDescuento NVARCHAR(80) NOT NULL DEFAULT ''
	) 
	
	CREATE TABLE RenglonesCuentaPOS (
		id BIGINT IDENTITY (1, 1) PRIMARY KEY NOT NULL,
		IDCuenta int NOT NULL DEFAULT 0,
		CodigoItem nvarchar (20) NOT NULL DEFAULT '',
		PrecioUnitario money NOT NULL DEFAULT 0,
		Cantidad float NOT NULL DEFAULT 0,
		NumeroRenglon int NOT NULL DEFAULT 0,
		Usuario nvarchar (20) NULL DEFAULT '',
		Precio money NOT NULL DEFAULT 0,
		idCombo INT NOT NULL DEFAULT 0
	) 
	
	ALTER TABLE RenglonesCuentaPOS ADD CONSTRAINT FK_RenglonesCuentaPOS_CuentasPOS
		FOREIGN KEY (IDCuenta) REFERENCES CuentasPOS (IDCuenta) ON DELETE CASCADE  ON UPDATE CASCADE 

	exec sp_executesql N'CREATE INDEX ndx_CuentaPOS_Owner ON CuentasPOS (tipo, ownerID)'

	CREATE TABLE renglonesComanda (
		numero bigint IDENTITY(1,1) PRIMARY KEY NOT NULL,
		cuenta int NOT NULL,
		codigoItem nvarchar(20) NOT NULL DEFAULT '',
		porcentajeIVA float NOT NULL DEFAULT 0,
		precio money NOT NULL DEFAULT 0,
		cantidad float NOT NULL DEFAULT 0,
		descripcion nvarchar(50) NOT NULL DEFAULT '',
		usuario nvarchar(20) not null default ''
	)

	ALTER TABLE renglonesComanda  ADD CONSTRAINT FK_renglonesComanda_CuentasPOS FOREIGN KEY(cuenta)
		REFERENCES CuentasPOS (IDCuenta)
		ON UPDATE CASCADE
		ON DELETE CASCADE
END

-- V7.2: Registro de descuentos

IF NOT Exists(SELECT * FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME = 'MotivosDescuento')
BEGIN
  Create Table MotivosDescuento (
    Codigo NVARCHAR(12) PRIMARY KEY NOT NULL,
    Descripcion NVARCHAR(40) NOT NULL,
    porcentaje float not null default 0,
    respetarMinimos tinyint not null default 1,
    nivelAutorizacion tinyint not null default 1,
    detallesModificables tinyint not null default 0
  )

  Create Table DescuentosSesion (
    id int IDENTITY (1, 1) PRIMARY KEY NOT NULL,
    sesion int not null, 
    codigoMotivo nvarchar(12) NOT NULL DEFAULT 'ERROR', 
    autorizadoDescuento nvarchar(12) NOT NULL DEFAULT 'ERROR',
    explicacionDescuento nvarchar(80) NOT NULL DEFAULT 'ERROR',
    porcentajeDescuento FLOAT NOT NULL DEFAULT 0,
    Hora DATETIME NOT NULL DEFAULT GETDATE(),
    numeroTicket INT NOT NULL DEFAULT 0,
    caja int not null default 0,
    valorOriginal money not null default 0,
    valorFinal money not null default 0
  )

  exec sp_executesql N'CREATE INDEX ndx_DescuentosSesion_Sesion ON DescuentosSesion (Sesion)'

  exec sp_executesql N'alter table DescuentosSesion 
    ADD CONSTRAINT FK_DescuentosSesion_Motivo
      FOREIGN KEY (CodigoMotivo)
      REFERENCES MotivosDescuento (Codigo)
      ON UPDATE CASCADE'
END

GO

-- En el ((ya no tan, aparentemente) improbable) caso de que venga de una beta de la 7.2:
IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'MotivosDescuento' AND COLUMN_NAME = 'detallesModificables')
BEGIN
  ALTER TABLE motivosDescuento
    ADD detallesModificables TINYINT NOT NULL DEFAULT 0
END

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'MotivosDescuento' AND COLUMN_NAME = 'porcentaje')
BEGIN
  ALTER TABLE motivosDescuento
    ADD porcentaje FLOAT NOT NULL DEFAULT 0
END

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'MotivosDescuento' AND COLUMN_NAME = 'respetarMinimos')
BEGIN
  ALTER TABLE motivosDescuento
    ADD respetarMinimos TINYINT NOT NULL DEFAULT 1
END

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'MotivosDescuento' AND COLUMN_NAME = 'nivelAutorizacion')
BEGIN
  ALTER TABLE motivosDescuento
    ADD nivelAutorizacion TINYINT NOT NULL DEFAULT 1
END

GO

IF NOT Exists(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'DescuentosSesion' AND COLUMN_NAME = 'numeroTicket')
BEGIN
  ALTER TABLE DescuentosSesion
    ADD numeroTicket INT NOT NULL DEFAULT 0
END

IF NOT Exists(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'DescuentosSesion' AND COLUMN_NAME = 'caja')
BEGIN
  ALTER TABLE DescuentosSesion
    ADD caja int not null default 0
END
    
IF NOT Exists(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'DescuentosSesion' AND COLUMN_NAME = 'valorOriginal')
BEGIN
  ALTER TABLE DescuentosSesion
    ADD valorOriginal money not null default 0
END
    
IF NOT Exists(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'DescuentosSesion' AND COLUMN_NAME = 'valorFinal')
BEGIN
  ALTER TABLE DescuentosSesion
    ADD valorFinal money not null default 0
END

GO

-- El descuento general se usa para registrar descuentos no-definidos, otorgados
-- desde aplicaciones que no usen los descuentos predefinidos (a la fecha, todas
-- menos clrCaja4)
IF NOT EXISTS(SELECT * FROM MotivosDescuento WHERE Codigo = 'GENERAL')
BEGIN
  INSERT INTO MotivosDescuento (Codigo, Descripcion, porcentaje, respetarMinimos, nivelAutorizacion, detallesModificables)
       VALUES ('GENERAL', 'Descuento general', 0, 1, 5, 1)
END

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'CuentasPOS' AND COLUMN_NAME = 'codigoDescuento')
BEGIN
  ALTER TABLE CuentasPOS
     ADD codigoDescuento NVARCHAR(12) NOT NULL DEFAULT '',
	 autorizadoDescuento NVARCHAR(12) NOT NULL DEFAULT '',
	 explicacionDescuento NVARCHAR(80) NOT NULL DEFAULT ''
END

IF NOT Exists(SELECT * FROM PerfilElementos WHERE Valor = 60)
BEGIN
	INSERT INTO perfilElementos (Valor, Descripcion, Posicion) VALUES ( 60 , 'Taller de reparaciones', 2510);
END

IF NOT Exists(SELECT * FROM PerfilElementos WHERE Valor = 61)
BEGIN
	INSERT INTO perfilElementos (Valor, Descripcion, Posicion) VALUES ( 61 , 'Modificar configuraciones de color', 976);
END

IF NOT Exists(SELECT * FROM PerfilElementos WHERE Valor = 62)
BEGIN
	INSERT INTO perfilElementos (Valor, Descripcion, Posicion) VALUES ( 62 , 'Seleccionar configuracion de color', 977);
END

IF NOT Exists(SELECT * FROM PerfilElementos WHERE Valor = 63)
BEGIN
	INSERT INTO perfilElementos (Valor, Descripcion, Posicion) VALUES ( 63 , 'Operar editor de menues', 605);
END

IF NOT Exists(SELECT * FROM PerfilElementos WHERE Valor = 64)
BEGIN
	INSERT INTO perfilElementos (Valor, Descripcion, Posicion) VALUES ( 64 , 'Editar tipos de descuento', 3810);
END

IF NOT Exists(SELECT * FROM PerfilElementos WHERE Valor = 65)
BEGIN
	INSERT INTO perfilElementos (Valor, Descripcion, Posicion) VALUES ( 65 , 'Editar perfiles de precios', 3820);
END

IF NOT Exists(SELECT * FROM PerfilElementos WHERE Valor = 66)
BEGIN
	INSERT INTO perfilElementos (Valor, Descripcion, Posicion) VALUES ( 66 , 'Definir medios de pago', 4050);
END

IF NOT Exists(SELECT * FROM PerfilElementos WHERE Valor = 67)
BEGIN
	INSERT INTO perfilElementos (Valor, Descripcion, Posicion) VALUES ( 67 , 'Editar libro de ventas', 2520);
END

IF NOT Exists(SELECT * FROM PerfilElementos WHERE Valor = 68)
BEGIN
	INSERT INTO perfilElementos (Valor, Descripcion, Posicion) VALUES ( 68 , 'Editar libro de compras', 4050);
END

IF NOT Exists(SELECT * FROM PerfilElementos WHERE Valor = 69)
BEGIN
	INSERT INTO perfilElementos (Valor, Descripcion, Posicion) VALUES ( 69 , 'Anotar retenciones IVA clientes', 2530);
END

IF NOT Exists(SELECT * FROM PerfilElementos WHERE Valor = 70)
BEGIN
	INSERT INTO perfilElementos (Valor, Descripcion, Posicion) VALUES ( 70 , 'Generar comprobantes de retencion', 1840);
END

IF NOT Exists(SELECT * FROM PerfilElementos WHERE Valor = 71)
BEGIN
	INSERT INTO perfilElementos (Valor, Descripcion, Posicion) VALUES ( 71 , 'Registrar retenciones del ISLR', 1841);
END

IF NOT Exists(SELECT * FROM PerfilElementos WHERE Valor = 72)
BEGIN
	INSERT INTO perfilElementos (Valor, Descripcion, Posicion) VALUES ( 72 , 'Ejecutar procesos de nomina', 4511);
END

IF NOT Exists(SELECT * FROM PerfilElementos WHERE Valor = 73)
BEGIN
	INSERT INTO perfilElementos (Valor, Descripcion, Posicion) VALUES ( 73 , 'Ejecutar scripts', 3500);
END

IF NOT Exists(SELECT * FROM PerfilElementos WHERE Valor = 74)
BEGIN
	INSERT INTO perfilElementos (Valor, Descripcion, Posicion) VALUES ( 74 , 'Ver reporte de excepciones', 2651);
END

IF NOT Exists(SELECT * FROM PerfilElementos WHERE Valor = 75)
BEGIN
	INSERT INTO perfilElementos (Valor, Descripcion, Posicion) VALUES ( 75 , 'Ver reportes de nomina', 3410);
END

IF NOT Exists(SELECT * FROM PerfilElementos WHERE Valor = 76)
BEGIN
	INSERT INTO perfilElementos (Valor, Descripcion, Posicion) VALUES ( 76 , 'Operar tabla de productos', 650);
END

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME = 'extDesc')
BEGIN
  CREATE TABLE extDesc (
    codigoItem NVARCHAR(20) PRIMARY KEY NOT NULL DEFAULT '',
    value NVARCHAR(4000) NOT NULL DEFAULT ''
  );
  
  exec sp_executesql N'alter table extDesc 
    ADD CONSTRAINT FK_ExtDesc_ItemsVenta
      FOREIGN KEY (codigoItem)
      REFERENCES itemsVenta (Codigo)
      ON UPDATE CASCADE ON DELETE CASCADE'
END

GO

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME = 'tmpTransferencias')
BEGIN
	CREATE TABLE tmpTransferencias (
		ID int IDENTITY (1, 1) PRIMARY KEY NOT NULL,
		FechaRegistro datetime NOT NULL,
		Descripcion nvarchar (50) NOT NULL,
		almacenOrigen nvarchar (8) NOT NULL,
		almacenDestino nvarchar (8) NOT NULL,
		operador nvarchar (12) NOT NULL,
		Notas nvarchar (255) NOT NULL 
	)

	CREATE TABLE tmpTransferenciasDetalles (
		Renglon int IDENTITY (1, 1) PRIMARY KEY NOT NULL,
		transID int NOT NULL,
		CodigoItem nvarchar (20) NOT NULL,
		Cantidad float NOT NULL DEFAULT 0
	)

	CREATE  UNIQUE  INDEX IX_tmpTransferenciasDetalles ON tmpTransferenciasDetalles(transID, Renglon)

	ALTER TABLE tmpTransferenciasDetalles ADD CONSTRAINT FK_tmpTransfDet_tmpTransf 
		FOREIGN KEY (transID) REFERENCES tmpTransferencias (ID)
		ON UPDATE CASCADE ON DELETE CASCADE
END

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'tmpTransferenciasDetalles' AND COLUMN_NAME = 'Renglon')
BEGIN
  ALTER TABLE tmpTransferenciasDetalles 
    ADD Renglon INT IDENTITY (1, 1) PRIMARY KEY NOT NULL
END

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'itemsVenta' AND COLUMN_NAME = 'porcentajeImputable')
BEGIN
	ALTER TABLE itemsVenta
		ADD porcentajeImputable FLOAT NOT NULL DEFAULT 0,
			Regulado TINYINT NOT NULL DEFAULT 0
END

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'condiciones' AND COLUMN_NAME = 'intervalo')
BEGIN
	ALTER TABLE Condiciones
	  ADD intervalo NVARCHAR(4) NOT NULL DEFAULT 'd'
END

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'facturasPOS' AND COLUMN_NAME = 'tipoConsumo')
BEGIN
	ALTER TABLE FacturasPOS
	  ADD tipoConsumo TINYINT NOT NULL DEFAULT 0
END

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME = 'chequeDevueltoComis')
BEGIN
	CREATE TABLE chequeDevueltoComis(
		id int IDENTITY(1,1) PRIMARY KEY NOT NULL,
		idCheque int NOT NULL DEFAULT 0,
		tipoDocRel nvarchar(3) NOT NULL DEFAULT '',
		refDocRel nvarchar(20) NOT NULL DEFAULT '',
		codigoVendedor nvarchar(15) NOT NULL DEFAULT '',
		montoComision money NOT NULL DEFAULT 0
	)

	exec sp_executesql N'ALTER TABLE chequeDevueltoComis  
		ADD  CONSTRAINT FK_chequeDevueltoComis_ChequesDevueltos FOREIGN KEY(idCheque)
		REFERENCES ChequesDevueltos (id)
			ON UPDATE CASCADE
			ON DELETE CASCADE'

	exec sp_executesql N'ALTER TABLE chequeDevueltoComis  
		ADD  CONSTRAINT FK_chequeDevueltoComis_Vendedores FOREIGN KEY(codigoVendedor)
		REFERENCES Vendedores (codigo)
			ON UPDATE CASCADE
			ON DELETE CASCADE'
END

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'comprobantes' AND COLUMN_NAME = 'documentoOrigen')
BEGIN
	ALTER TABLE Comprobantes
	  ADD documentoOrigen NVARCHAR(3) NOT NULL DEFAULT '',
	  numeroDocumentoOrigen INT NOT NULL DEFAULT 0

	exec sp_executesql N'CREATE INDEX ndxDocumento ON Comprobantes (documentoOrigen, numeroDocumentoOrigen)'
END

GO

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.ROUTINES WHERE SPECIFIC_NAME = 'ExtraerLinea')
BEGIN
  exec sp_executesql N'CREATE FUNCTION ExtraerLinea(@d AS NVARCHAR(255), @w AS SMALLINT, @lineIndex AS TINYINT)
  RETURNS NVARCHAR(255) 
  AS BEGIN
	DECLARE @nextCh nvarchar(1), @isDone TINYINT
	DECLARE @ndx SMALLINT
	DECLARE @n SMALLINT, @p1 SMALLINT, @p2 SMALLINT
	DECLARE @resto nvarchar(255), @temp NVARCHAR(255), @retVal NVARCHAR(255)

	IF @lineIndex < 1 RETURN ''''

	SET @ndx = 1
	SET @resto = @d

	WHILE LEN(@resto) > @w
	BEGIN
		SET @resto = LTRIM(RTRIM(@resto))
		SET @n = 1
		WHILE UNICODE(SUBSTRING(@resto, @n, 1)) < 32 SET @n = @n + 1
		IF @n > 1 SET @resto = SUBSTRING(@resto, @n, LEN(@resto))

		-- Busca un retorno de carro (CR) ...
		SET @p1 = CHARINDEX(NCHAR(13), @resto)
		IF @p1 != 0 And @p1 <= @w
		BEGIN
			SET @p2 = CHARINDEX(NCHAR(10), @resto)
			IF @p2 < @p1 SET @p1 = @p2
			SET @temp = SUBSTRING(@resto, 1, @p1 - 1)
			SET @resto = SUBSTRING(@resto, @p1 + 1, 160)
		END 
		ELSE BEGIN
			SET @temp = LEFT(@resto, @w)
			SET @isDone = 0
			SET @n = @w

			WHILE @isDone = 0 AND @n > 0
			BEGIN
				SET @nextCh = SUBSTRING(@temp, @n, 1)
				If @nextCh = '' ''
				BEGIN
					SET @n = @n - 1
					SET @isDone = 1
				END ELSE
				BEGIN
					IF CHARINDEX(@nextCh, '',.:;'') > 0 SET @isDOne = 1
				END
				IF @isDone = 0 SET @n = @n - 1
			END
			IF @isDone = 0 SET @n = @w
			SET @temp = LEFT(@temp, @n)
		END
		SET @resto = SUBSTRING(@resto, LEN(@temp) + 1, LEN(@resto))
		IF @ndx = @lineIndex RETURN @temp
		SET @ndx = @ndx + 1
	END
	SET @resto = LTRIM(RTRIM(@resto))
	SET @resto = LEFT(@resto, @w)
	IF @ndx = @lineIndex RETURN @resto
	RETURN ''''
  END'
END

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME = 'controlMesasSesion')
BEGIN
	CREATE TABLE controlMesasSesion(
		idSesion int PRIMARY KEY NOT NULL DEFAULT 0,
		nCuentasInicial smallint NOT NULL DEFAULT 0,
		montoCuentasInicial money NOT NULL DEFAULT 0,
		nCuentasAbiertas smallint NOT NULL DEFAULT 0,
		montoCargado money NOT NULL DEFAULT 0,
		nCuentasEliminadas smallint NOT NULL DEFAULT 0,
		montoEliminado money NOT NULL DEFAULT 0,
		nTransferencias smallint NOT NULL DEFAULT 0,
		montoTransferencias money NOT NULL DEFAULT 0,
		nCuentasPendientes smallint NOT NULL DEFAULT 0,
		montoCuentasPendientes money NOT NULL DEFAULT 0,
		nCerradas smallint NOT NULL DEFAULT 0,
		montoCerrado money NOT NULL DEFAULT 0)
END

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'RelacionesIVARetenido' AND COLUMN_NAME = 'Reporte')
BEGIN
	ALTER TABLE RelacionesIVARetenido
	  ADD Reporte INT NOT NULL DEFAULT 0
	  
	EXEC sp_executeSQL N'UPDATE RelacionesIVARetenido SET Reporte = D.Reporte 
							FROM DocumentosFiscales D
							WHERE Month(D.Fecha) = Month(RelacionesIVARetenido.Fecha)
							AND YEAR(D.Fecha) = Year(RelacionesIVARetenido.Fecha)
							AND D.Reporte <> 0'
END

-- V7.7
IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'CuentasPOS' AND COLUMN_NAME = 'porcentajeDescuento')
BEGIN
	ALTER TABLE CuentasPOS
		ADD porcentajeDescuento FLOAT NOT NULL DEFAULT 0
END

-- V6.8: por algun motivo, no apareca en ninguno de los upgrade
IF NOT Exists(SELECT * FROM INFORMATION_SCHEMA.Tables WHERE TABLE_NAME = 'ChequesDevueltos')
BEGIN
  CREATE TABLE ChequesDevueltos(
  	id int IDENTITY(1,1) PRIMARY KEY NOT NULL,
  	CodigoCliente nvarchar(20) NOT NULL,
  	Descripcion nvarchar(50) NOT NULL,
  	FechaDevolucion datetime NOT NULL,
  	CodigoEmisor nvarchar(20) NOT NULL,
  	NumeroDocumento nvarchar(20) NOT NULL,
  	Monto money NOT NULL,
  	MontoPenalizacion money NOT NULL,
  	Saldo money NOT NULL,
  )
  	exec sp_executesql N'ALTER TABLE chequeDevueltoComis  CREATE INDEX ix_ChequesDevueltosCliente ON ChequesDevueltos (CodigoCliente, FechaDevolucion)'
END

-- V7.8

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.PARAMETERS WHERE SPECIFIC_NAME = 'costoFecha')
BEGIN
	exec sp_executesql N'CREATE FUNCTION costoFecha(@fo AS DATETIME)
		RETURNS @retTable TABLE
			(	codigoItem nvarchar(20), 
				fechaOperacion DATETIME,
				costo MONEY
			)
		AS
		BEGIN
			INSERT @retTable
				SELECT codigoItem, FechaOperacion, Costo
				FROM DetallesMINV D1
				WHERE NumeroDocumento * 10000 + Renglon = (
					SELECT MAX(NumeroDocumento * 10000 + Renglon)
					FROM (SELECT * FROM DetallesMINV D2
					WHERE CodigoItem = D1.CodigoItem 
					AND FechaOperacion = (
						SELECT MAX(FechaOperacion) FROM DetallesMINV D2
						WHERE FechaOperacion < @fo
						AND Costo <> 0
						AND CodigoItem = D1.CodigoItem)
					) D3
				)
			RETURN
		END'
END


IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'CuentasPOS' AND COLUMN_NAME = 'horaBloqueo')
BEGIN
	ALTER TABLE CuentasPOS
		ADD horaBloqueo DATETIME NOT NULL DEFAULT getdate()
END

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'nomDetallesProceso' AND COLUMN_NAME = 'cantidad')
BEGIN
  ALTER TABLE nomDetallesProceso ADD cantidad FLOAT NOT NULL DEFAULT 0
END

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'correlativosMaquina' AND COLUMN_NAME = 'proximaNC') 
BEGIN
  ALTER TABLE correlativosMaquina ADD proximaNC INT NOT NULL DEFAULT 1
END

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'correlativosMaquina' AND COLUMN_NAME = 'serialPF') 
BEGIN
  ALTER TABLE correlativosMaquina ADD serialPF NVARCHAR(14) NOT NULL DEFAULT ''
END

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'sesionesPOS' AND COLUMN_NAME = 'primeraNC') 
BEGIN
  ALTER TABLE sesionesPOS ADD 
    primeraNC INT NOT NULL DEFAULT 0, 
    ultimaNC INT NOT NULL DEFAULT 0, 
    montoNC MONEY NOT NULL DEFAULT 0, 
    impuestoNC MONEY NOT NULL DEFAULT 0
  ALTER TABLE sesionesCerradas ADD
    primeraNC INT NOT NULL DEFAULT 0, 
    ultimaNC INT NOT NULL DEFAULT 0, 
    montoNC MONEY NOT NULL DEFAULT 0, 
    impuestoNC MONEY NOT NULL DEFAULT 0
END

IF NOT Exists(SELECT * FROM information_schema.tables WHERE TABLE_NAME = 'NCPOS')
BEGIN
  CREATE TABLE NCPOS (
  	numero int IDENTITY(1,1) PRIMARY KEY NOT NULL,
  	idSesion int NOT NULL,
  	Hora datetime NOT NULL DEFAULT (getdate()),
  	idMaquina int NOT NULL,
  	correlativo int NOT NULL,
  	montoVenta money NOT NULL DEFAULT 0,
  	Impuesto money NOT NULL,
  	idMaquinaOrigen int NOT NULL,
  	correlativoOrigen int NOT NULL,
  	fechaOrigen datetime NOT NULL,
  	numeroNotaRelacionada int NOT NULL DEFAULT 0,
  	codigoCliente nvarchar(20) NOT NULL DEFAULT ''
  )
	
	CREATE UNIQUE INDEX ndxCorrelativo
		ON NCPOS (idMaquina, Correlativo)

	CREATE UNIQUE INDEX ndxSesion
		ON NCPOS (idSesion, numero)

  CREATE TABLE NCPOSdetalles (
  	id int IDENTITY(1,1) PRIMARY KEY NOT NULL,
  	idNCPOS int NOT NULL,
  	codigoItem nvarchar(20) NOT NULL,
  	cantidad float NOT NULL,
  	precio money NOT NULL,
  	porcentajeImpuesto float NOT NULL
  )

  ALTER TABLE NCPOSdetalles  ADD  CONSTRAINT FK_NCPOSdetalles_NCPOSdetalles FOREIGN KEY(idNCPOS)
  REFERENCES dbo.NCPOS (numero)
  ON UPDATE CASCADE
  ON DELETE CASCADE
END

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'rislrMetodos' AND COLUMN_NAME = 'Codigo')
BEGIN
	ALTER TABLE rislrMetodos ADD Codigo SMALLINT NOT NULL DEFAULT 0
END 
GO

UPDATE rislrMetodos SET codigo = 2 WHERE idConcepto = 1 AND TipoPersona = 0
UPDATE rislrMetodos SET codigo = 3 WHERE idConcepto = 1 AND TipoPersona = 1
UPDATE rislrMetodos SET codigo = 4 WHERE idConcepto = 1 AND TipoPersona = 2
UPDATE rislrMetodos SET codigo = 5 WHERE idConcepto = 1 AND TipoPersona = 3
UPDATE rislrMetodos SET codigo = 18 WHERE idConcepto = 2 AND TipoPersona = 0
UPDATE rislrMetodos SET codigo = 19 WHERE idConcepto = 2 AND TipoPersona = 1
UPDATE rislrMetodos SET codigo = 20 WHERE idConcepto = 2 AND TipoPersona = 2
UPDATE rislrMetodos SET codigo = 21 WHERE idConcepto = 2 AND TipoPersona = 3
UPDATE rislrMetodos SET codigo = 22 WHERE idConcepto = 3 AND TipoPersona = 1
UPDATE rislrMetodos SET codigo = 23 WHERE idConcepto = 3 AND TipoPersona = 3
UPDATE rislrMetodos SET codigo = 25 WHERE idConcepto = 4 AND TipoPersona = 0
UPDATE rislrMetodos SET codigo = 26 WHERE idConcepto = 4 AND TipoPersona = 1
UPDATE rislrMetodos SET codigo = 27 WHERE idConcepto = 4 AND TipoPersona = 2
UPDATE rislrMetodos SET codigo = 24 WHERE idConcepto = 4 AND TipoPersona = 3
UPDATE rislrMetodos SET codigo = 29 WHERE idConcepto = 5 AND TipoPersona = 3
UPDATE rislrMetodos SET codigo = 30 WHERE idConcepto = 6 AND TipoPersona = 3
UPDATE rislrMetodos SET codigo = 71 WHERE idConcepto = 7 AND TipoPersona = 0
UPDATE rislrMetodos SET codigo = 72 WHERE idConcepto = 7 AND TipoPersona = 2
UPDATE rislrMetodos SET codigo = 32 WHERE idConcepto = 8 AND TipoPersona = 1
UPDATE rislrMetodos SET codigo = 33 WHERE idConcepto = 8 AND TipoPersona = 3
UPDATE rislrMetodos SET codigo = 34 WHERE idConcepto = 9 AND TipoPersona = 1
UPDATE rislrMetodos SET codigo = 35 WHERE idConcepto = 9 AND TipoPersona = 3
UPDATE rislrMetodos SET codigo = 36 WHERE idConcepto = 10 AND TipoPersona = 1
UPDATE rislrMetodos SET codigo = 37 WHERE idConcepto = 10 AND TipoPersona = 3
UPDATE rislrMetodos SET codigo = 38 WHERE idConcepto = 11 AND TipoPersona = 1
UPDATE rislrMetodos SET codigo = 39 WHERE idConcepto = 11 AND TipoPersona = 3
UPDATE rislrMetodos SET codigo = 40 WHERE idConcepto = 12 AND TipoPersona = 3
UPDATE rislrMetodos SET codigo = 41 WHERE idConcepto = 13 AND TipoPersona = 0
UPDATE rislrMetodos SET codigo = 42 WHERE idConcepto = 13 AND TipoPersona = 1
UPDATE rislrMetodos SET codigo = 43 WHERE idConcepto = 13 AND TipoPersona = 2
UPDATE rislrMetodos SET codigo = 44 WHERE idConcepto = 13 AND TipoPersona = 3
UPDATE rislrMetodos SET codigo = 45 WHERE idConcepto = 14 AND TipoPersona = 0
UPDATE rislrMetodos SET codigo = 46 WHERE idConcepto = 14 AND TipoPersona = 1
UPDATE rislrMetodos SET codigo = 47 WHERE idConcepto = 14 AND TipoPersona = 2
UPDATE rislrMetodos SET codigo = 48 WHERE idConcepto = 14 AND TipoPersona = 3
UPDATE rislrMetodos SET codigo = 53 WHERE idConcepto = 15 AND TipoPersona = 0
UPDATE rislrMetodos SET codigo = 54 WHERE idConcepto = 15 AND TipoPersona = 1
UPDATE rislrMetodos SET codigo = 55 WHERE idConcepto = 15 AND TipoPersona = 2
UPDATE rislrMetodos SET codigo = 56 WHERE idConcepto = 15 AND TipoPersona = 3
UPDATE rislrMetodos SET codigo = 57 WHERE idConcepto = 16 AND TipoPersona = 0
UPDATE rislrMetodos SET codigo = 58 WHERE idConcepto = 16 AND TipoPersona = 1
UPDATE rislrMetodos SET codigo = 59 WHERE idConcepto = 16 AND TipoPersona = 2
UPDATE rislrMetodos SET codigo = 60 WHERE idConcepto = 16 AND TipoPersona = 3
UPDATE rislrMetodos SET codigo = 61 WHERE idConcepto = 17 AND TipoPersona = 0
UPDATE rislrMetodos SET codigo = 62 WHERE idConcepto = 17 AND TipoPersona = 1
UPDATE rislrMetodos SET codigo = 63 WHERE idConcepto = 17 AND TipoPersona = 2
UPDATE rislrMetodos SET codigo = 64 WHERE idConcepto = 17 AND TipoPersona = 3
UPDATE rislrMetodos SET codigo = 83 WHERE idConcepto = 18 AND TipoPersona = 0
UPDATE rislrMetodos SET codigo = 84 WHERE idConcepto = 18 AND TipoPersona = 2
UPDATE rislrMetodos SET codigo = 85 WHERE idConcepto = 18 AND TipoPersona = 3

GO

-- V 7.14
IF PATINDEX('%SQL Server%2000%-%', @@Version) = 0
BEGIN
	DECLARE @indexName nvarchar(128), @ndxCount INT

	SELECT @indexName = COALESCE(sys.indexes.name, 'NONE')
		FROM sys.indexes
			INNER JOIN sys.tables ON sys.tables.object_id = sys.indexes.object_id
			INNER JOIN sys.index_columns ON sys.index_columns.index_id = sys.indexes.index_id
				AND sys.index_columns.object_id = sys.tables.object_id
			INNER JOIN sys.columns ON sys.columns.column_id = sys.index_columns.column_id
				AND sys.columns.object_id = sys.tables.object_id
		WHERE sys.tables.name = 'CierresZ' And sys.columns.name = 'NumeroUnico' And is_unique = 0

	IF @indexName = '' Or @indexName IS NULL SET @indexName = 'NONE'

	IF @indexName != 'NONE'
	BEGIN
	  DECLARE @cmd nvarchar(100)
	  SET @cmd = 'DROP INDEX ' + @indexName + ' ON cierresZ'
	  EXEC sp_executesql @cmd
	END

	SELECT @ndxCount = COUNT(*)
		FROM sys.indexes
			INNER JOIN sys.tables ON sys.tables.object_id = sys.indexes.object_id
			INNER JOIN sys.index_columns ON sys.index_columns.index_id = sys.indexes.index_id
				AND sys.index_columns.object_id = sys.tables.object_id
			INNER JOIN sys.columns ON sys.columns.column_id = sys.index_columns.column_id
				AND sys.columns.object_id = sys.tables.object_id
		WHERE sys.tables.name = 'CierresZ' And sys.columns.name = 'NumeroUnico' And is_unique = 1

	IF @ndxCount = 0
	BEGIN
	  CREATE UNIQUE INDEX ndxNumeroZ  ON CierresZ (numeroUnico)
	END

	IF NOT Exists(SELECT * FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME = 'AcumuladoresTipoIVAZ')
	BEGIN
		CREATE TABLE AcumuladoresTipoIVAZ (
			numero bigint IDENTITY(1,1) PRIMARY KEY,
			numeroZ bigint NOT NULL,
			TipoImpuesto nvarchar(3) NOT NULL,
			BaseImponible money NOT NULL,
			Porcentaje float NOT NULL,
			valor money NOT NULL
		)

		ALTER TABLE AcumuladoresTipoIVAZ  ADD  CONSTRAINT FK_AcumuladoresTipoIVAZ_CierresZ FOREIGN KEY(numeroZ)
			REFERENCES CierresZ (NumeroUnico)
			ON UPDATE Cascade
			ON DELETE Cascade

		INSERT INTO acumuladoresTipoIVAZ (numeroZ, TipoImpuesto, BaseImponible, Porcentaje, valor)
			SELECT numeroUnico, 'IV1', gravable1, FLOOR(impuesto1 / Gravable1 * 200 + 0.5) / 2, impuesto1
			FROM CierresZ where gravable1 <> 0 AND not exists (select * from AcumuladoresTipoIVAZ where numeroZ = CierresZ.NumeroUnico AND TipoImpuesto = 'IV1')

		INSERT INTO acumuladoresTipoIVAZ (numeroZ, TipoImpuesto, BaseImponible, Porcentaje, valor)
			SELECT numeroUnico, 'IV2', gravable2, FLOOR(impuesto2 / Gravable2 * 200 + 0.5) / 2, impuesto2
			FROM CierresZ where gravable2 <> 0 AND not exists (select * from AcumuladoresTipoIVAZ where numeroZ = CierresZ.NumeroUnico AND TipoImpuesto = 'IV2')

		INSERT INTO acumuladoresTipoIVAZ (numeroZ, TipoImpuesto, BaseImponible, Porcentaje, valor)
			SELECT numeroUnico, 'EXE', Exento, 0, 0
			FROM CierresZ where Exento <> 0 AND not exists (select * from AcumuladoresTipoIVAZ where numeroZ = CierresZ.NumeroUnico AND TipoImpuesto = 'EXE')
	END
END

IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME = 'detallesDocFis')
BEGIN
	CREATE TABLE detallesDocFis (
		Id bigint IDENTITY(1,1) PRIMARY KEY NOT NULL,
		docId bigint NOT NULL,
		codigoTipo nvarchar(3) NOT NULL,
		base money NOT NULL,
		porcentaje float NOT NULL,
		impuesto money NOT NULL
	)

	ALTER TABLE detallesDocFis  ADD  CONSTRAINT FK_detallesDocFis_DocumentosFiscales FOREIGN KEY(docId)
		REFERENCES DocumentosFiscales (Id)
		ON UPDATE CASCADE
		ON DELETE CASCADE

	INSERT INTO detallesDocFis (docId, codigoTipo, base, porcentaje, impuesto)
		SELECT ID, 'IV1', Gravable1, Tasa1, Impuesto1
		FROM DocumentosFiscales
		WHERE Gravable1 != 0

	INSERT INTO detallesDocFis (docId, codigoTipo, base, porcentaje, impuesto)
		SELECT ID, 'IV2', Gravable2, Tasa2, Impuesto2
		FROM DocumentosFiscales
		WHERE Gravable2 != 0

	INSERT INTO detallesDocFis (docId, codigoTipo, base, porcentaje, impuesto)
		SELECT ID, 'EXE', Exento, 0, 0
		FROM DocumentosFiscales
		WHERE Exento != 0
END


-- V7.15: agregar Almacen a cotizaciones....
IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'Cotizaciones' AND COLUMN_NAME = 'Almacen')
BEGIN
	ALTER TABLE Cotizaciones ADD Almacen NVARCHAR(8) NOT NULL DEFAULT ''
END


-- V7.16: Agregar descripciones para genericos en aplicaciones de punto de ventas
IF NOT EXISTS(SELECT * FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME = 'descripcionRS')
BEGIN
	CREATE TABLE descripcionRS(
		SessionID int NOT NULL,
		NumeroRenglon smallint NOT NULL,
		Descripcion nvarchar(60) NOT NULL DEFAULT '',
	 CONSTRAINT PK_descripcionRS PRIMARY KEY CLUSTERED 
		(
			SessionID ASC,
			NumeroRenglon ASC
		)
	)

	ALTER TABLE descripcionRS  WITH CHECK ADD  CONSTRAINT FK_descripcionRS_RenglonesSesion FOREIGN KEY(SessionID, NumeroRenglon)
		REFERENCES RenglonesSesion (SessionID, NumeroRenglon)
		ON UPDATE CASCADE
		ON DELETE CASCADE

	CREATE TABLE descripcionRCP(
		idRenglon bigint PRIMARY KEY NOT NULL,
		descripcion nvarchar(60) NOT NULL DEFAULT '',
	)

	ALTER TABLE descripcionRCP  WITH CHECK ADD  CONSTRAINT FK_descripcionRCP_RenglonesCuentaPOS FOREIGN KEY(idRenglon)
		REFERENCES RenglonesCuentaPOS (id)
		ON UPDATE CASCADE
		ON DELETE CASCADE

	CREATE TABLE descripcionRFP(
		idMaquina int NOT NULL,
		numeroTicket int NOT NULL,
		numeroLinea smallint NOT NULL,
		descripcion nvarchar(60) NOT NULL DEFAULT '',
		 CONSTRAINT PK_descripcionRFP PRIMARY KEY CLUSTERED 
		(
			idMaquina ASC,
			numeroTicket ASC,
			numeroLinea ASC
		)
	)

	ALTER TABLE descripcionRFP  WITH CHECK ADD  CONSTRAINT FK_descripcionRFP_RenglonesFacturaPOS FOREIGN KEY(idMaquina, numeroTicket, numeroLinea)
	REFERENCES RenglonesFacturaPOS (idMaquina, numeroTicket, numeroLinea)
	ON UPDATE CASCADE
	ON DELETE CASCADE
END

IF NOT EXISTS(SELECT * FROM SYSINDEXES WHERE NAME = 'ndxPOS')
BEGIN 
	CREATE INDEX ndxPOS ON DetallesItemVenta (numeroDocumento, tipoDocumento, codigoItem, codigoVendedor, codigoCliente, PrecioVenta)
END
